# coding: utf-8

"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr
from internal_integration_handler_connector.models.portal_member import PortalMember

class SendMessageInGroupChat(BaseModel):
    """
    SendMessageInGroupChat
    """
    portal_id: StrictInt = Field(...)
    portal_member: PortalMember = Field(...)
    message: StrictStr = Field(...)
    chat_id: StrictInt = Field(...)
    __properties = ["portal_id", "portal_member", "message", "chat_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SendMessageInGroupChat:
        """Create an instance of SendMessageInGroupChat from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of portal_member
        if self.portal_member:
            _dict['portal_member'] = self.portal_member.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SendMessageInGroupChat:
        """Create an instance of SendMessageInGroupChat from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SendMessageInGroupChat.parse_obj(obj)

        _obj = SendMessageInGroupChat.parse_obj({
            "portal_id": obj.get("portal_id"),
            "portal_member": PortalMember.from_dict(obj.get("portal_member")) if obj.get("portal_member") is not None else None,
            "message": obj.get("message"),
            "chat_id": obj.get("chat_id")
        })
        return _obj


